@@ -5,16 +5,10 @@ Modules handling chemical composition
 import string
 from jarvis.core.specie import Specie
 from collections import OrderedDict
+from collections import defaultdict
+from jarvis.core.utils import gcd
+import re
 
-def gcd(a, b):
-    """Calculate the Greatest Common Divisor of a and b.
-
-    Unless b==0, the result will have the same sign as b (so that when
-    b is divided by it, the result comes out positive).
-    """
-    while b:
-        a, b = b, a % b
-    return a
 
 
 class Composition(object):
@@ -29,6 +23,24 @@ class Composition(object):
         if sort:
             content = OrderedDict(sorted(content.items(), key=lambda x: (x[0])))
         self._content = content
+   
+    @staticmethod 
+
+    def from_string(value,sort=True):
+        re_formula = re.compile('([A-Z][a-z]?)([0-9\.]*)')
+        d = defaultdict(float)
+        for elt, amt in re_formula.findall(value):
+            if elt in ['D', 'T']:
+                elt = 'H'
+            if amt == '':
+                d[elt] = 1
+            elif float(amt).is_integer():
+                d[elt] += int(float(amt))
+            else:
+                d[elt] += float(amt)
+
+        comp = Composition(dict(d),sort=sort)
+        return comp
 
     def reduce(self):
         repeat = 0
@@ -62,14 +74,21 @@ class Composition(object):
         form = ""
         reduced, repeat = self.reduce()
         for specie, count in reduced.items():
-            form = form + specie + str(count)
+            if float(count).is_integer():
+                form = form + specie + str(int(count))
+            else:
+                form = form + specie + str(count)
+
         return form.replace("1", "")
 
     @property
     def formula(self):
         form = ""
         for specie, count in self._content.items():
-            form = form + str(specie) + str(count)
+            if float(count).is_integer():
+                form = form + str(specie) + str(int(count))
+            else:
+                form = form + str(specie) + str(count)
         return form.replace("1", "")
 
     @property
@@ -85,6 +104,10 @@ class Composition(object):
 
 """
 if __name__ == "__main__":
+    c=Composition.from_string('Al2O3Al5Co6O1')
+    print ('Al2O3Al5Co6O1',c.formula, c.reduced_formula)
+    import sys
+    sys.exit()
     comp = {"Li": 2, "O": 4}
     cc = Composition(comp)
     print("dict", cc.to_dict())
